"""
Command-line tool to retrieve document attachments.
"""

from argparse import ArgumentParser
import sys
import base64
import os

from ..config import Config
from ..api import Adonis


def main():
    parser = ArgumentParser(description="Retrieve document attachments")
    parser.add_argument("scanneddocno", help="Scanned document number")
    parser.add_argument(
        "-o", "--output", help="Output file path (default: document_{scanneddocno}.pdf)"
    )
    args = parser.parse_args()

    config = Config()
    api = Adonis.fromConfig(config)

    try:
        result = api.getAttachment(args.scanneddocno)

        # Default output filename if not specified
        output_path = (
            args.output if args.output else f"document_{args.scanneddocno}.pdf"
        )

        if "FileBase64" in result:
            file_data = result["FileBase64"]

            # Remove potential data URL prefix
            if ";" in file_data and "," in file_data:
                file_data = file_data.split(",", 1)[1]

            # Decode and write to file
            with open(output_path, "wb") as f:
                f.write(base64.b64decode(file_data))

            print(f"Document saved to {output_path}")
        else:
            print("No document data found in response")

        return 0
    except Exception as e:
        print(f"Error: {e}")
        return 1


if __name__ == "__main__":
    sys.exit(main())
