"""
Command-line tool to get certificates for crew members.
"""

from argparse import ArgumentParser
import sys
import json

from ..config import Config
from ..api import Adonis


def main():
    parser = ArgumentParser(description="Get certificates for crew members")
    parser.add_argument("pin", nargs="+", help="One or more crew PINs")
    parser.add_argument(
        "-f",
        "--format",
        choices=["json", "table"],
        default="json",
        help="Output format (default: json)",
    )
    args = parser.parse_args()

    config = Config()
    api = Adonis.fromConfig(config)

    results = {}

    for pin in args.pin:
        try:
            crew_certs = api.getCompetences(pin)
            results[pin] = crew_certs["Documents"]
        except Exception as e:
            print(f"Error retrieving certificates for PIN {pin}: {e}")

    if args.format == "json":
        print(json.dumps(results, indent=2))
    else:  # table format
        if not results:
            print("No certificates found.")
            return 0

        print("PIN | Code | Description | Issue Date | Expiry Date | Number | Status")
        print("-" * 80)

        for pin, certificates in results.items():
            if not certificates:
                print(f"{pin} | No certificates found")
                continue

            for cert in certificates:
                print(
                    f"{pin} | {cert.get('Code', '')} | {cert.get('Description', '')} | "
                    f"{cert.get('DateFrom', '')} | {cert.get('ExpiryDate', '')} | "
                    f"{cert.get('Number', '')} | {cert.get('Validity', '')}"
                )

    return 0


if __name__ == "__main__":
    sys.exit(main())
