"""
Command-line tool to fetch crew data for given PINs.
"""

from argparse import ArgumentParser
from json import dumps

from ..config import Config
from ..api import Adonis


def main():
    parser = ArgumentParser(description="Fetch crew data for given PINs")
    parser.add_argument("pin", nargs="+", help="One or more crew PINs")
    args = parser.parse_args()

    config = Config()
    api = Adonis.fromConfig(config)

    data = dict()

    for pin in args.pin:
        crewdata = dict()

        crew = api.getCrew(pin)

        crewdata["firstName"] = crew.firstName
        crewdata["middleName"] = crew.middleName
        crewdata["lastName"] = crew.lastName
        crewdata["dob"] = crew.birthDate
        crewdata["password"] = crew.birthDate.replace("-", "")
        crewdata["email"] = crew.email
        crewdata["profilePicture"] = crew.profilePicture

        data[pin] = crewdata

    print(dumps(data))


if __name__ == "__main__":
    main()
