"""
Command-line tool to view survey requirements.
"""

from argparse import ArgumentParser
import sys
import json

from ..config import Config
from ..api import Adonis


def main():
    parser = ArgumentParser(description="View survey requirements")
    parser.add_argument("-f", "--format", choices=["json", "table"], default="json",
                      help="Output format (default: json)")
    args = parser.parse_args()

    config = Config()
    api = Adonis.fromConfig(config)

    try:
        data = api.getCrewListView("PW001SRV903")
        
        if args.format == "json":
            print(json.dumps(data, indent=2))
        else:  # table format
            result_data = json.loads(data.get("Result", "[]"))
            
            if not result_data:
                print("No survey requirements found.")
                return 0
                
            # Get headers from first item
            headers = list(result_data[0].keys())
            
            # Calculate column widths
            col_widths = {header: max(len(header), max(len(str(item.get(header, ""))) for item in result_data)) 
                         for header in headers}
            
            # Print header
            header_row = " | ".join(f"{header:{col_widths[header]}}" for header in headers)
            print(header_row)
            print("-" * len(header_row))
            
            # Print data rows
            for item in result_data:
                row = " | ".join(f"{str(item.get(header, '')):{col_widths[header]}}" for header in headers)
                print(row)
                
        return 0
    except Exception as e:
        print(f"Error: {e}")
        return 1


if __name__ == "__main__":
    sys.exit(main())